Ptah Framework
==============

.. toctree::
   :maxdepth: 2
   
   tutorial.rst
   rdbms.rst
   manageui.rst
   forms.rst
   authentication.rst
   scripts.rst
   faq.rst
   api.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

